Attribute VB_Name = "SetActiveWnd"
   Option Explicit
  
   Private Const SW_SHOW As Long = 5&
   Private Const SW_RESTORE As Long = 9&
   
   ' API declares, constants and types
   Private Const API_FALSE As Long = 0&
   Private Const API_TRUE As Long = 1&
   
   Private Declare Function FindWindow Lib "user32" Alias "FindWindowA" (ByVal lpClassName As String, ByVal lpWindowName As String) As Long
   
   Private Declare Function ShowWindow Lib "user32" (ByVal hwnd&, ByVal nCmdShow&) As Long
   Private Declare Function SetForegroundWindow Lib "user32" (ByVal hwnd&) As Long
   
   ' declares used to make the previous instance the foreground window in WIn98 & 2K
   ' since MS changed the behavior of the SetForegroundWindow call in these OS'
   Private Declare Function IsIconic Lib "user32" (ByVal hwnd&) As Long
   Private Declare Function GetWindowThreadProcessId Lib "user32" (ByVal hwnd&, lpdwProcessId&) As Long
   Private Declare Function AttachThreadInput Lib "user32" (ByVal idAttach&, ByVal idAttachTo&, ByVal fAttach&) As Long
   Private Declare Function GetForegroundWindow Lib "user32" () As Long
   Private Declare Function BringWindowToTop Lib "user32" (ByVal hwnd&) As Long

Public Sub ActivatePrevInstance(ByVal hAppWindow&)
         
  ' activate the thread for the previous instance.  we have to go through all of this
  ' because MS has changed the behavior of the SetForgroundWindow API function so that
  ' it will no longer bring a window in another process to the foreground.  the reason
  ' for this is that many developers have abused the use of SetForegroundWindow by
  ' bringing their apps to the foreground unnecessarily and steeling the focus from
  ' other windows while the other window was in use.  if you've ever had this happen,
  ' you know how annoying it is.  unfortunately, the change in the behavior of
  ' SetForegroundWindow leaves us with no simple way to accomplish bringing a window to
  ' the foreground when it is really necessary.
   
  Dim fShowWindowFlag&, hWndForeground&, nCurThreadID&, nNextThreadID&

  ' tell the previous instance to restore itself incase it's minimized
  If IsIconic(hAppWindow) Then
    fShowWindowFlag = SW_RESTORE
  Else
    fShowWindowFlag = SW_SHOW
  End If
   
  Call ShowWindow(hAppWindow, fShowWindowFlag)
  
   
  hWndForeground = GetForegroundWindow()
  
  ' see if the window is already the foreground window.
  If hAppWindow <> hWndForeground Then
    ' if not, we need to get the thread IDs for this app and the current foreground window
    nCurThreadID = GetWindowThreadProcessId(hWndForeground, ByVal 0&)
    nNextThreadID = GetWindowThreadProcessId(hAppWindow, ByVal 0&)
      
    ' the active window.
    If nCurThreadID <> nNextThreadID Then
      ' if the thread IDs are not the same, attach to the foreground
      ' thread long enough to make our window the foreground window
      Call AttachThreadInput(nCurThreadID, nNextThreadID, API_TRUE)
      Call BringWindowToTop(hAppWindow)
      Call SetForegroundWindow(hAppWindow)
      Call AttachThreadInput(nCurThreadID, nNextThreadID, API_FALSE)
      
    Else
      Call BringWindowToTop(hAppWindow)
      Call SetForegroundWindow(hAppWindow)
    End If
   End If
   
End Sub

Public Function findhwndwithtitle(hwndtitle As String) As Long
   findhwndwithtitle = FindWindow(vbNullString, hwndtitle)
End Function
